@@ -15,7 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+ * USA.
  */
 
 #include <config.h>
@@ -455,7 +456,7 @@ ksba_cert_get_digest_algo (ksba_cert_t cert)
  * @cert: certificate object 
  * 
  * This function returnes the serial number of the certificate.  The
- * serial number is an integer returned as an cancnical encoded
+ * serial number is an integer returned as an canonical encoded
  * S-expression with just one element.
  * 
  * Return value: An allocated S-Exp or NULL for no value.
@@ -1464,7 +1465,7 @@ ksba_cert_get_ext_key_usages (ksba_cert_t cert, char **result)
 static gpg_error_t
 parse_distribution_point (const unsigned char *der, size_t derlen, 
                           ksba_name_t *distpoint, ksba_name_t *issuer,
-                          unsigned int *reason)
+                          ksba_crl_reason_t *reason)
 {
   gpg_error_t err;
   struct tag_info ti;
@@ -1623,7 +1624,7 @@ gpg_error_t
 ksba_cert_get_crl_dist_point (ksba_cert_t cert, int idx,
                               ksba_name_t *r_distpoint,
                               ksba_name_t *r_issuer,
-                              unsigned int *r_reason)
+                              ksba_crl_reason_t *r_reason)
 {
   gpg_error_t err;
   const char *oid;
